NAME
Pinto::Package - Represents a single record in the 02packages.details.txt file
VERSION
version 0.015
DESCRIPTION
This is a private module for internal use only. There is nothing for you to see here (yet).
METHODS
to_string()
Returns this Package as a string containing the package name. This is what you get when you evaluate and Package in double quotes.
to_index_string()
Returns this Package object as a string that is suitable for writing to an 02packages.details.txt file.
AUTHOR
Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
COPYRIGHT AND LICENSE
This software is copyright (c) 2011 by Imaginative Software Systems.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.